# newfile
create files from preset template cli app

- [Docs](https://github.com/teeaz/newfile)
- [Examples](https://github.com/teeaz/newfile/tree/main/example)

## template globals
- `now` 
- `filename`
- `dirname`
- `pwd`
- `git_dir`
- `params` 
- `args`
- `_tl_`： Low context handle


## TODO

- 递归父目录查找模板文件
- 关联文件创建支持(一个初始项目通常是多个文件)
- 在模板内定义输出文件
- 全局模板管理()
